@@ -45,13 +45,25 @@ def _json_dumps():
 @cached_function
 def _env():
     import jinja2
-    return jinja2.Environment(
+    import pysi
+
+    env = jinja2.Environment(
         loader = jinja2.FunctionLoader(obj_from_str(cfg.TEMPLATE_LOADER)),
         autoescape = True,
         cache_size = cfg.TEMPLATE_CACHE_SIZE,
         auto_reload = cfg.TEMPLATE_AUTO_RELOAD,
         extensions = cfg.JINJA2_EXTENSIONS,
     )
+    env.globals = cfg.JINJA2_GLOBALS or {
+            'url4': pysi.url4,
+            'cfg': pysi.cfg,
+            'static_url': pysi.static_url,
+
+            'xrange': xrange,
+            'enumerate': enumerate,
+            'len': len,
+    }
+    return env
 
 class FileLoader(object):
     mtimes = {}
