@@ -32,7 +32,7 @@ class Request(object):
 
     @cached_property
     def context(self):
-        res = {'rq': self, 'url4': url4, 'cfg': cfg, 'static_url': static_url}
+        res = {'rq': self}
         for func in cfg.CONTEXT_PROCESSORS:
             res.update(func(self))
         return res
